<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Teach Kiddo
 * @since Teach Kiddo 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'teach_kiddo_counter_section', array(
	'title'             => esc_html__( 'Counters','teach-kiddo' ),
	'description'       => esc_html__( 'Counters Section options.', 'teach-kiddo' ),
	'panel'             => 'teach_kiddo_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_counter_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[counter_section_enable]', array(
        'selector'            => '#counter-section .tooltiptext',
        'settings'            => 'teach_kiddo_theme_options[counter_section_enable]',
    ) );
}


$wp_customize->add_setting( 'teach_kiddo_theme_options[counter_image]', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'teach_kiddo_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'teach-kiddo' ),
		'section'     		=> 'teach_kiddo_counter_section',
		'active_callback'	=> 'teach_kiddo_is_counter_section_enable',
) ) );



for ( $i = 1; $i <= 4; $i++ ) :

	// counter note control and setting
	$wp_customize->add_setting( 'teach_kiddo_theme_options[counter_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Teach_Kiddo_Icon_Picker( $wp_customize, 'teach_kiddo_theme_options[counter_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'teach-kiddo' ), $i ),
		'section'           => 'teach_kiddo_counter_section',
		'active_callback'	=> 'teach_kiddo_is_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'teach_kiddo_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'teach_kiddo_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'teach-kiddo' ), $i ),
		'section'        	=> 'teach_kiddo_counter_section',
		'active_callback' 	=> 'teach_kiddo_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'teach_kiddo_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'teach_kiddo_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'teach-kiddo' ), $i ),
		'section'        	=> 'teach_kiddo_counter_section',
		'active_callback' 	=> 'teach_kiddo_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'teach_kiddo_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Teach_Kiddo_Customize_Horizontal_Line( $wp_customize, 'teach_kiddo_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'teach_kiddo_counter_section',
			'active_callback' => 'teach_kiddo_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;