<?php
/**
 * service Section options
 *
 * @package Theme Palace
 * @subpackage Teach Kiddo
 * @since Teach Kiddo 1.0.0
 */

// Add service section
$wp_customize->add_section( 'teach_kiddo_service_section', array(
	'title'             => esc_html__( 'Service','teach-kiddo' ),
	'description'       => esc_html__( 'Service Section options.', 'teach-kiddo' ),
	'panel'             => 'teach_kiddo_front_page_panel',
) );

// service content enable control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_service_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
) ) );


if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[service_section_enable]', array(
		'selector'            => '#service-section .tooltiptext',
		'settings'            => 'teach_kiddo_theme_options[service_section_enable]',
    ) );
}


// service title setting and control
$wp_customize->add_setting( 'teach_kiddo_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'teach_kiddo_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'teach-kiddo' ),
	'section'        	=> 'teach_kiddo_service_section',
	'active_callback' 	=> 'teach_kiddo_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[service_title]', array(
		'selector'            => '#service-section .section-header h2',
		'settings'            => 'teach_kiddo_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'teach_kiddo_service_title_partial',
    ) );
}


// long Excerpt length setting and control.
$wp_customize->add_setting( 'teach_kiddo_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_number_range',
	'validate_callback' => 'teach_kiddo_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
	) );

$wp_customize->add_control( 'teach_kiddo_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'teach-kiddo' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'teach-kiddo' ),
	'section'     		=> 'teach_kiddo_service_section',
	'active_callback' 	=> 'teach_kiddo_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );


for ( $i = 1; $i <= 4; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'teach_kiddo_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( new Teach_Kiddo_Icon_Picker( $wp_customize, 'teach_kiddo_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'teach-kiddo' ), $i ),
		'section'           => 'teach_kiddo_service_section',
		'active_callback'	=> 'teach_kiddo_is_service_section_enable',
		) ) );


	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'teach_kiddo_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'teach_kiddo_sanitize_page',
	) );

	$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'teach-kiddo' ), $i ),
		'section'           => 'teach_kiddo_service_section',
		'choices'			=> teach_kiddo_page_choices(),
		'active_callback'	=> 'teach_kiddo_is_service_section_enable',
	) ) );

    $wp_customize->add_setting( 'teach_kiddo_theme_options[service_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Teach_Kiddo_Customize_Horizontal_Line( $wp_customize, 'teach_kiddo_theme_options[service_hr_'. $i .']',
        array(
            'section'           => 'teach_kiddo_service_section',
            'active_callback'   => 'teach_kiddo_is_service_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;
