<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Teach Kiddo
 * @since Teach Kiddo 1.0.0
 */

// Add team section
$wp_customize->add_section( 'teach_kiddo_team_section', array(
	'title'             => esc_html__( 'Team','teach-kiddo' ),
	'description'       => esc_html__( 'Team Section options.', 'teach-kiddo' ),
	'panel'             => 'teach_kiddo_front_page_panel',
) );

// team content enable control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_team_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[team_section_enable]', array(
		'selector'            => '#team-section .tooltiptext',
		'settings'            => 'teach_kiddo_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'teach_kiddo_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'teach_kiddo_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'teach-kiddo' ),
	'section'        	=> 'teach_kiddo_team_section',
	'active_callback' 	=> 'teach_kiddo_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[team_title]', array(
		'selector'            => '#team-section h2.section-title',
		'settings'            => 'teach_kiddo_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'teach_kiddo_team_title_partial',
    ) );
}


// team content type control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'teach_kiddo_sanitize_select',
) );

$wp_customize->add_control( 'teach_kiddo_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'teach_kiddo_is_team_section_enable',
	'choices'			=> teach_kiddo_popular_team_content_type(),
) );

for ( $i = 1; $i <= 4; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'teach_kiddo_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'teach_kiddo_sanitize_page',
	) );

	$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'teach-kiddo' ), $i ),
		'section'           => 'teach_kiddo_team_section',
		'choices'			=> teach_kiddo_page_choices(),
		'active_callback'	=> 'teach_kiddo_is_team_section_content_page_enable',
	) ) );
	if ( class_exists( 'TP_Education' ) ) {
		// team pages drop down chooser control and setting
		$wp_customize->add_setting( 'teach_kiddo_theme_options[team_content_team_' . $i . ']', array(
			'sanitize_callback' => 'teach_kiddo_sanitize_page',
		) );

		$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[team_content_team_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Teacher %d', 'teach-kiddo' ), $i ),
			'section'           => 'teach_kiddo_team_section',
			'choices'			=> teach_kiddo_team_choices(),
			'active_callback'	=> 'teach_kiddo_is_team_section_content_team_enable',
		) ) );
	}
	
	// team custom content
	$wp_customize->add_setting( 'teach_kiddo_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'teach_kiddo_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'teach-kiddo' ), $i ),
		'section'           => 'teach_kiddo_team_section',
		'active_callback'	=> 'teach_kiddo_is_team_section_content_position_social_enable',
	) );

	// team social
	$wp_customize->add_setting( 'teach_kiddo_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Teach_Kiddo_Multi_Input_Custom_Control( $wp_customize, 'teach_kiddo_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'teach-kiddo' ),
		'button_text'       => esc_html__( 'Add social.', 'teach-kiddo' ),
		'section'           => 'teach_kiddo_team_section',
		'active_callback' 	=> 'teach_kiddo_is_team_section_content_position_social_enable',
	) ) );

// team hr setting and control
	$wp_customize->add_setting( 'teach_kiddo_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Teach_Kiddo_Customize_Horizontal_Line( $wp_customize, 'teach_kiddo_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'teach_kiddo_team_section',
			'active_callback' => 'teach_kiddo_is_team_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;



